==> joounit-0.9.5.jar: joo/classes/flexunit/framework/TestSuiteTestListener.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{

   import flash.events.*;
   import flash.utils.*;*/
   "public class TestSuiteTestListener implements flexunit.framework.TestListener",1,function($$private){var $$bound=joo.boundMethod;return[function(){joo.classLoader.init(flash.events.TimerEvent);},
   

       "public function TestSuiteTestListener",function TestSuiteTestListener$(suite/* : TestSuite*/, result/* : TestResult*/)
       {
           this.suite$1 = suite;
           this.result$1 = result;
           result.addListener(/*flexunit.framework.TestListener*/(this));
           //the Timer allows us to let frames progress and kill the deep recursion problem
           this.timer$1 = new flash.utils.Timer(5, 1);
           this.timer$1.addEventListener("timer", $$bound(this,"handleTimer"));
           if ($$private.listenerStack == null)
           {
               $$private.listenerStack = new Array();
           }
           else
           {
               result.removeListener(/*flexunit.framework.TestListener*/($$private.listenerStack[0]));
           }
           $$private.listenerStack.unshift(this);
       },

       "public function endTest",function endTest( test/* : Test*/ )/* : void*/
       {
           if ($$private.listenerStack[0] != this)
           {
               //trace('TSTL.endTest ignored');
               return;
           }
           //BUG 114824 WORKAROUND
           this.timer$1.removeEventListener(flash.events.TimerEvent.TIMER, $$bound(this,"handleTimer"));
           this.timer$1 = new flash.utils.Timer(5, 1);
           this.timer$1.addEventListener(flash.events.TimerEvent.TIMER, $$bound(this,"handleTimer"));
           //END WORKAROUND
           this.timer$1.start();
       },

       "public function handleTimer",function handleTimer(event/* : Event*/)/* : void*/
       {
           this.suite$1.runNext(this.result$1);
       },

       "public function pop",function pop()/* : void*/
       {
           var popped/* : TestSuiteTestListener*/ = $$private.listenerStack.shift();
           //assertEquals(this, popped);
           this.result$1.removeListener(/*flexunit.framework.TestListener*/(this));
           if ($$private.listenerStack.length > 0)
           {
               this.result$1.addListener(/*flexunit.framework.TestListener*/($$private.listenerStack[0]));
               $$private.listenerStack[0].endTest(null);
           }
       },

       "public function addError",function addError( test/* : Test*/, error/* : Error*/ )/* : void*/ { },

       "public function addFailure",function addFailure( test/* : Test*/, error/* : AssertionFailedError*/ )/* : void*/ { },

       "public function startTest",function startTest( test/* : Test*/ )/* : void*/ { },

       "private static var",{ listenerStack/* : Array*/:null},
       "private var",{ suite/* : TestSuite*/:null},
       "private var",{ result/* : TestResult*/:null},
       "private var",{ timer/* : Timer*/:null},
   ];},[],["flexunit.framework.TestListener","flash.utils.Timer","Array","flash.events.TimerEvent"], "0.8.0", "0.9.5"
);

==> joounit-1.0.0.jar: joo/classes/flexunit/framework/TestSuiteTestListener.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{

   import flash.events.*;
   import flash.utils.*;*/
   "public class TestSuiteTestListener implements flexunit.framework.TestListener",1,function($$private){var $$bound=joo.boundMethod,$1=flexunit.framework,$2=flash.utils,$3=flash.events;return[function(){joo.classLoader.init(flash.events.TimerEvent);},
   

       "public function TestSuiteTestListener",function TestSuiteTestListener(suite/* : TestSuite*/, result/* : TestResult*/)
       {
           this.suite$1 = suite;
           this.result$1 = result;
           result.addListener(/*TestListener*/(this));
           //the Timer allows us to let frames progress and kill the deep recursion problem
           this.timer$1 = new $2.Timer(5, 1);
           this.timer$1.addEventListener("timer", $$bound(this,"handleTimer"));
           if ($$private.listenerStack == null)
           {
               $$private.listenerStack = new Array();
           }
           else
           {
               result.removeListener(/*TestListener*/($$private.listenerStack[0]));
           }
           $$private.listenerStack.unshift(this);
       },

       "public function endTest",function endTest( test/* : Test*/ )/* : void*/
       {
           if ($$private.listenerStack[0] != this)
           {
               //trace('TSTL.endTest ignored');
               return;
           }
           //BUG 114824 WORKAROUND
           this.timer$1.removeEventListener($3.TimerEvent.TIMER, $$bound(this,"handleTimer"));
           this.timer$1 = new $2.Timer(5, 1);
           this.timer$1.addEventListener($3.TimerEvent.TIMER, $$bound(this,"handleTimer"));
           //END WORKAROUND
           this.timer$1.start();
       },

       "public function handleTimer",function handleTimer(event/* : Event*/)/* : void*/
       {
           this.suite$1.runNext(this.result$1);
       },

       "public function pop",function pop()/* : void*/
       {
           var popped/* : TestSuiteTestListener*/ = $$private.listenerStack.shift();
           //assertEquals(this, popped);
           this.result$1.removeListener(/*TestListener*/(this));
           if ($$private.listenerStack.length > 0)
           {
               this.result$1.addListener(/*TestListener*/($$private.listenerStack[0]));
               $$private.listenerStack[0].endTest(null);
           }
       },

       "public function addError",function addError( test/* : Test*/, error/* : Error*/ )/* : void*/ { },

       "public function addFailure",function addFailure( test/* : Test*/, error/* : AssertionFailedError*/ )/* : void*/ { },

       "public function startTest",function startTest( test/* : Test*/ )/* : void*/ { },

       "private static var",{ listenerStack/* : Array*/:null},
       "private var",{ suite/* : TestSuite*/:null},
       "private var",{ result/* : TestResult*/:null},
       "private var",{ timer/* : Timer*/:null},
   undefined];},[],["flexunit.framework.TestListener","flash.utils.Timer","Array","flash.events.TimerEvent"], "0.8.0", "1.0.0"
);
